# Export local e-model to Nexus

To export an e-model built locally to Nexus, start by copying the ``export_local_to_nexus.py`` script and the YAML files (forge.yml and nsg.yml) into your local e-model folder. This folder should already contain the following files created during the e-model construction process:

- ``final.json``: which contains the analysis of each optimised model
- ``run/<GITHASH>``: folder named after the githash of the commit generated by the run you wish to export.
    - ``config/``: folder containing the configuration files
    - ``morphologies/``: folder containing the morphology file
- ``figures/``: folder containing the figures generated by the analysis step of the local e-model pipeline
- ``export_emodels_hoc/``: folder containing the hoc file generated by the export step of the local e-model pipeline.

Please ensure that you run both the analysis and export hoc step of the local e-model pipeline, see [here](https://github.com/BlueBrain/BluePyEModel/tree/main/examples/L5PC#running-the-different-steps).

Once all the required files are in place, adjust the variables in the script to match the e-model data you wish to export, as well as the Nexus-related settings. Additionally, verify that the electrophysiological data, mechanisms, and morphology are registered in the Nexus project to which you want to export the e-model.
The script is designed exclusively to create the e-model related resources within the specified Nexus project and link the respective data registered on Nexus.

Once everything is set, run the script to export the e-model to Nexus:
```
python export_local_to_nexus.py
```

If the script runs successfully, the following e-model resources will be created in the specified Nexus project:
- ``EModelPipelineSettings`` (EMPS): the pipeline settings of the e-model.
- ``ExtractionTargetsConfiguration`` (ETC): the extraction target configuration of the e-model from the ``run/{githash}/config/extract_config`` folder, as well as the links to the ephys data.
- ``EModelConfiguration`` (EMC): the configuration of the e-model, which links to the morphology and mechanisms and stores a reformatted version of the parameters file of the e-model from ``run/{githash}/config/params`` folder.
- ``FitnessCalculatorConfiguration`` (FCC): the fitness calculator configuration of the e-model, which stores the features and protocols of the e-model from ``run/{githash}/config/features/`` folder.
- ``EmodelScript`` (ES): the hoc file of the e-model.
- ``EModel`` (EM): all the information related to an optimised e-model. It contains the final parameters of the e-model from final.json, and pdfs of the e-model distribution plots, features scores and e-model response traces. It also links to EModelWorflow.
- ``EModelWorkflow`` (EMW): the resource to which all the above resources are linked also contains the workflow state.

The graph structure of the e-model resources is shown below:

```
    EModelWorkflow
        |
        ├──> EModelPipelineSettings
        |
        ├──> ExtractionTargetsConfiguration
        |       |
        |       ├──> Trace1
        |       ├──> ...
        |       └──> TraceN
        |
        ├──> EModelConfiguration
        |       |
        |       ├──> Mechanism1
        |       ├──> ...
        |       └──> MechanismN
        |       └──> Morphology
        |
        ├──> FitnessCalculatorConfiguration
        |
        ├──> EModel
        |
        └──> EModelScript
```

## Troubleshooting: Delays in Resource Registration with Nexus
During the resource registration process, errors may occur if the resource is not yet fully registered and therefore not ready to be retrieved from Nexus. To address this, the ``sleep_time`` variable in the script can be adjusted ensuring the resource fully registers with Nexus and becomes retrievable.